@@ -54,6 +54,11 @@ impl TypeReader {
                     continue;
                 }
 
+                // TODO: workaround for https://github.com/microsoft/win32metadata/issues/725
+                if type_name == TypeName::new("Windows.Win32.System.Diagnostics.Debug", "DISPATCHER_CONTEXT_ARM64") {
+                    continue;
+                }
+
                 let extends = def.extends();
 
                 if extends == TypeName::Attribute {
@@ -89,8 +94,6 @@ impl TypeReader {
             }
         }
 
-        // TODO: remove Windows.Win32.Interop namespace
-
         Self { nested, types }
     }
 
@@ -149,6 +152,10 @@ impl TypeReader {
         self.nested.get(&enclosing.row)
     }
 
+    pub fn get_type_entry<T: HasTypeName>(&'static self, type_name: T) -> Option<&TypeEntry> {
+        self.types.get_namespace(type_name.namespace()).and_then(|tree| tree.get_type(type_name.name()))
+    }
+
     pub fn get_type<T: HasTypeName>(&'static self, type_name: T) -> Option<&ElementType> {
         self.types.get_namespace(type_name.namespace()).and_then(|tree| tree.get_type(type_name.name())).and_then(|entry| entry.def.first())
     }
